@@ -293,13 +293,13 @@ class MintStick:
         if os.geteuid() > 0:
             polkit_exec = 'pkexec'
             self.process = Popen(
-                [polkit_exec, '/usr/bin/python3', '-u', '/usr/lib/mintstick/raw_format.py', '-d', usb_path_arg,
-                 '-f', fstype, '-l', label, '-u', str(os.geteuid()), '-g', str(os.getgid())],
+                [polkit_exec, '/usr/bin/mint-stick-format', '-d', usb_path_arg,
+                 '-f', fstype, '-u', str(os.geteuid()), '-g', str(os.getgid()), '--', label],
                 shell=False, stdout=PIPE, preexec_fn=os.setsid)
         else:
             self.process = Popen(
-                ['/usr/bin/python3', '-u', '/usr/lib/mintstick/raw_format.py', '-d', usb_path_arg,
-                 '-f', fstype, '-l', label, '-u', str(os.geteuid()), '-g', str(os.getgid())],
+                ['/usr/bin/mint-stick-format', '-d', usb_path_arg,
+                 '-f', fstype, '-u', str(os.geteuid()), '-g', str(os.getgid()), "--", label],
                 shell=False, stdout=PIPE, preexec_fn=os.setsid)
 
         self.progressbar.show()
@@ -308,7 +308,6 @@ class MintStick:
         GLib.timeout_add(500, self.check_format_job)
 
     def format_job_done(self, rc):
-        self.set_progress(1.0)
         if rc == 0:
             self.show_format_result("dialog-information", _('The USB stick was formatted successfully.'))
             return False
@@ -316,10 +315,15 @@ class MintStick:
             message = _("An error occured while creating a partition on %s.") % usb_path
         elif rc == 127:
             message = _('Authentication Error.')
+        elif rc == 126:  # Cancelled by the user.
+            self.clear_progress()
+            message = None
         else:
             message = _('An error occurred.')
-        self.show_format_result("dialog-error", message)
-        self.set_format_sensitive()
+
+        if message is not None:
+            self.show_format_result("dialog-error", message)
+        self.set_format_sensitive(False)
         self.udisks_client.handler_unblock(self.udisk_listener_id)
         return False
 
@@ -339,6 +343,7 @@ class MintStick:
 
         self.udisks_client.handler_block(self.udisk_listener_id)
         self.go_button.set_sensitive(False)
+        self.verify_button.set_sensitive(False)
         self.devicelist.set_sensitive(False)
         self.chooser.set_sensitive(False)
         self.progressbar.show()
@@ -352,6 +357,10 @@ class MintStick:
         XApp.set_window_progress_pulse(self.window, False)
         XApp.set_window_progress(self.window, int_progress)
 
+    def clear_progress(self):
+        self.progressbar.hide()
+        XApp.set_window_progress_pulse(self.window, False)
+
     def pulse_progress(self):
         self.progressbar.pulse()
         XApp.set_window_progress_pulse(self.window, True)
@@ -390,11 +399,11 @@ class MintStick:
         if os.geteuid() > 0:
             polkit_exec = 'pkexec'
             self.process = Popen(
-                [polkit_exec, '/usr/bin/python3', '-u', '/usr/lib/mintstick/raw_write.py', '-s', source, '-t', target],
+                [polkit_exec, '/usr/bin/mint-stick-write', '-s', source, '-t', target],
                 shell=False, stdout=PIPE, preexec_fn=os.setsid)
         else:
             self.process = Popen(
-                ['/usr/bin/python3', '-u', '/usr/lib/mintstick/raw_write.py', '-s', source, '-t', target],
+                ['/usr/bin/mint-stick-write', '-s', source, '-t', target],
                 shell=False, stdout=PIPE, preexec_fn=os.setsid)
 
         self.write_progress = 0
@@ -416,9 +425,15 @@ class MintStick:
             message = _('An error occured while copying the image.')
         elif rc == 127:
             message = _('Authentication Error.')
+        elif rc == 126:  # Cancelled by the user.
+            self.clear_progress()
+            self.set_iso_sensitive()
+            message = None
         else:
             message = _('An error occurred.')
-        self.show_result("dialog-error", message)
+        if message is not None:
+            self.show_format_result("dialog-error", message)
+
         return False
 
     def show_format_result(self, icon_name, text):
@@ -431,11 +446,6 @@ class MintStick:
         self.wTree.get_object("result_image").set_from_icon_name(icon_name, Gtk.IconSize.DIALOG)
         self.wTree.get_object("result_label").set_text(text)
 
-    def final_unsensitive(self):
-        self.chooser.set_sensitive(False)
-        self.devicelist.set_sensitive(False)
-        self.go_button.set_sensitive(False)
-
     def close(self, widget):
         if self.process is not None:
             try:
@@ -454,9 +464,11 @@ class MintStick:
         self.chooser.set_sensitive(True)
         self.devicelist.set_sensitive(True)
         self.go_button.set_sensitive(True)
+        self.verify_button.set_sensitive(True)
 
-    def set_format_sensitive(self):
-        self.get_devices()
+    def set_format_sensitive(self, reset=True):
+        if reset:
+            self.get_devices()
         self.filesystemlist.set_sensitive(True)
         self.devicelist.set_sensitive(True)
         self.go_button.set_sensitive(True)
